@@ -8,15 +8,14 @@ also the power of for instance all the %-magic functions that IPython has to
 offer.
 
 """
-from __future__ import unicode_literals
+from __future__ import unicode_literals, print_function
 
-from prompt_toolkit import AbortAction
-from prompt_toolkit import Exit
 from prompt_toolkit.completion import Completion, Completer
 from prompt_toolkit.contrib.completers import PathCompleter, WordCompleter, SystemCompleter
 from prompt_toolkit.contrib.regular_languages.compiler import compile
 from prompt_toolkit.contrib.regular_languages.completion import GrammarCompleter
 from prompt_toolkit.contrib.regular_languages.lexer import GrammarLexer
+from prompt_toolkit.shortcuts import create_eventloop
 from prompt_toolkit.document import Document
 from prompt_toolkit.layout.controls import TokenListControl
 
@@ -170,14 +169,17 @@ class InteractiveShellEmbed(_InteractiveShellEmbed):
         def get_globals():
             return self.user_ns
 
+        self._eventloop = create_eventloop()
         self._cli = IPythonCommandLineInterface(
-            self, get_globals=get_globals, vi_mode=vi_mode,
+            self,
+            eventloop=self._eventloop,
+            get_globals=get_globals, vi_mode=vi_mode,
             history_filename=history_filename)
 
     def raw_input(self, prompt=''):
         print('')
         try:
-            string = self._cli.cli.read_input(on_exit=AbortAction.RAISE_EXCEPTION).text
+            string = self._cli.cli.read_input().text
 
             # In case of multiline input, make sure to append a newline to the input,
             # otherwise, IPython will ask again for more input in some cases.
@@ -185,7 +187,7 @@ class InteractiveShellEmbed(_InteractiveShellEmbed):
                 return string + '\n\n'
             else:
                 return string
-        except Exit:
+        except EOFError:
             self.ask_exit()
             return ''
 
